@@ -62,10 +62,8 @@
 #undef HAVE_PLOT_H
 #endif
 
-#if defined (BUILD_HTTP)
-#define HAVE_STDINT_H
-#else
-#undef HAVE_STDINT_H
+#if defined (BUILD_WWW)
+#undef BUILD_WWW
 #endif
 
 #if defined (HAVE_CURSES)
@@ -120,11 +118,11 @@
 #define PACKAGE_BUGREPORT "Marcel van der Veer <algol68g@xs4all.nl>"
 
 // Define to the full name and version of this package.
-#define PACKAGE_STRING "algol68g 3.2.1"
+#define PACKAGE_STRING "algol68g 3.4.2"
 
 // Define to the version of this package.
-#define PACKAGE_VERSION "3.2.1"
+#define PACKAGE_VERSION "3.4.2"
 
 // Version number of package
-#define VERSION "3.2.1"
+#define VERSION "3.4.2"
 
